=== BeepMate - Forms to your messaging app ===
Contributors: beepmate
Tags: whatsapp, forms, contact form, messaging, notifications
Requires at least: 5.0
Tested up to: 6.7.2
Stable tag: 1.1.2
Requires PHP: 7.0
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html

Automatically send WordPress form submissions to WhatsApp instead of or alongside emails. Get instant notifications and respond to inquiries quickly.

== Description ==

**BeepMate** connects your WordPress site's forms directly to WhatsApp. Whenever a visitor submits a form on your website, you'll receive an instant WhatsApp message with their information.

### Key Benefits

* **Instant Notifications**: Get form submissions delivered to your WhatsApp in real-time
* **Better Response Times**: Reply to inquiries directly from your phone, wherever you are
* **Works With Any Form**: Compatible with all WordPress form plugins that use the mail system
* **No Complex Setup**: Works automatically with your existing forms
* **Attachment Support**: Receives files submitted through forms

### How It Works

The plugin integrates with WordPress's email system to capture form submissions and redirect them to WhatsApp using the BeepMate API. It works alongside your existing email notifications, ensuring you never miss an important message.
You do not need to configure SMTP or any mailer settings (unless you want to) - it works even without a mailer.

### Features

* Works with all WordPress form plugins (Contact Form 7, Gravity Forms, WPForms, Ninja Forms, Forminator etc.)
* Simple configuration with your BeepMate API key
* Multiple API connection methods for compatibility with all hosting environments
* Preserves special characters and emoji
* Debug mode for troubleshooting
* Maintains your existing email workflow

### Requirements

* WordPress 5.0 or higher
* PHP 7.0 or higher
* A BeepMate account (get your FREE account and FREE API key at [beepmate.io](https://beepmate.io))
* A WhatsApp account

== Installation ==

1. Upload the plugin files to the `/wp-content/plugins/beepmate` directory, or install the plugin through the WordPress plugins screen.
2. Activate the plugin through the 'Plugins' screen in WordPress.
3. Navigate to Settings → BeepMate Forms to WhatsApp to configure the plugin.
4. Enter your BeepMate API key and WhatsApp User ID that you received from BeepMate when creating the account.
5. Select "Enable" for "Submit forms to WhatsApp" to enable the plugin.
6. Use the "Test Your Configuration" section to send a test message.

== Frequently Asked Questions ==

= Does this replace email notifications? =

No, by default the plugin sends WhatsApp messages alongside your regular email notifications. Your existing email workflow remains unchanged.

= Which form plugins are supported? =

The plugin works with any WordPress form plugin that uses the standard WordPress mail system, including Contact Form 7, Gravity Forms, WPForms, Ninja Forms, and many others.

= Do I need to modify my forms? =

No, the plugin works with your existing forms without any modifications needed.

= How do I get a BeepMate API key? =

Visit [beepmate.io](https://beepmate.io) to create an account and obtain your API key.

= Does it support file attachments? =

Yes, the plugin can forward file attachments from forms to WhatsApp. 

= How are special characters handled? =

The plugin includes special processing to ensure characters like "<" and ">" are properly displayed in WhatsApp messages.

== Screenshots ==

1. Plugin settings page.
2. Test message configuration.
3. Example of a form submission received on WhatsApp.

== Changelog ==

= 1.1.2 =
* Improved WhatsApp notifications
* Added support for file attachments on forms
* Fixed links inside forms

= 1.1.1 =
* Added multiple API connection methods
* Improved compatibility with different hosting environments
* Added debug mode option

= 1.1.0 =
* Production release

= 1.0.0 =
* Initial release

== Technical Details ==

### How It Works Technically

BeepMate intercepts WordPress emails at the PHPMailer level, right before they're sent. When a form is submitted:

1. The plugin hooks into `phpmailer_init` to capture the email content
2. It extracts the recipient, subject, message body, and any attachments
3. The information is formatted for WhatsApp
4. The plugin connects to the BeepMate API using one of three methods (cURL, file_get_contents, or exec)
5. The message is delivered to your configured WhatsApp number

All of this happens without modifying your existing forms or email system.

### Configuration Options

**BeepMate API Key**: Your unique API key from BeepMate that authorizes the connection.

**User ID**: The phone number (with country code, no spaces or symbols) that will receive the WhatsApp messages.

**Redirect All Forms**: When set to "Yes," all form submissions will be sent to WhatsApp. When "No," the plugin remains inactive.

**API Method**: The technical approach used to connect to the BeepMate API:
- **cURL**: The recommended method, works on most servers.
- **file_get_contents**: An alternative if cURL is disabled on your server.
- **exec**: Uses system commands, useful on certain restrictive hosting environments.

**Debug Mode**: Enables detailed logging for troubleshooting.

### Debugging

If you're experiencing issues with the plugin, you can enable Debug Mode in the settings. This will log detailed information about:
- Form interceptions
- Message preparation
- API calls
- Response codes and errors

Logs can be found in your WordPress debug log (if WP_DEBUG is enabled) or in your server's PHP error log.

### API Structure

The plugin uses BeepMate's API with the following structure:
- For text-only messages: `https://beepmate.io/send?key=YOUR_KEY&id=YOUR_ID&msg=MESSAGE`
- For messages with attachments: A POST request to `https://beepmate.io/send` with multipart/form-data

### Security Considerations

The plugin:
- Sanitizes all user input
- Uses WordPress nonces for form submissions
- Checks user capabilities before allowing settings changes
- Hides the API key in logs
- Properly escapes all output

### Extending the Plugin

Developers can hook into the plugin's functionality using these functions:
- `beepmate_whatsapp_forms_prepare_message`: Formats message content for WhatsApp
- `beepmate_whatsapp_forms_send_to_beepmate`: Handles the API connection
- `beepmate_whatsapp_forms_debug`: Controls debug logging

### Known Limitations

- Currently supports sending to a single WhatsApp number
- Depends on the standard WordPress email system being used by forms
- Some form plugins that implement custom email sending may not be compatible

